function [eye,saccade,interval] = PostHoc(rawdata,chosenphase,fishlist,threshold,slowpause,slowduration)

% For debugging, copy this line to the command window:
% PostHoc('D:\Florian\dataforposthoc.txt',2,1,.5,2)

% datafile = 'D:\Florian\dataforposthoc.txt';
% datafile = 'D:\Florian\debugging_182.0_StimulusProtocol.txt';

  eye.raw = rawdata;
  eye.time = eye.raw(:,1);
  eye.leftpos = eye.raw(:,5);
  eye.rightpos = eye.raw(:,6);
  eye.stimphase = eye.raw(:,end);
  
  % Reset time such that the trial starts at t=0.
  eye.time = eye.time - min(eye.time);
  
  for k = fishlist

    eye.leftpos = eye.raw(:,3+2*k);
    eye.rightpos = eye.raw(:,4+2*k);

    % Chop full data set into small chunks, each corresponding to exactly
    % one stimulus phase.
    
    indexthisphase = eye.stimphase==chosenphase;
    eye.rightposeachphase{k} = eye.rightpos(indexthisphase);
    eye.leftposeachphase{k}  = eye.leftpos(indexthisphase);
    eye.timeeachphase{k}     = eye.time(indexthisphase);
  
    % For this chunk of data (= this stimulus phase), detect saccade times,
    % saccade numbers per minute.
    [saccade.righteye{k}, saccade.rightindex{k}] = PostHocDetectSaccade(threshold,eye.timeeachphase{k},eye.rightposeachphase{k});
    [saccade.lefteye{k},  saccade.leftindex{k}]  = PostHocDetectSaccade(threshold,eye.timeeachphase{k},eye.leftposeachphase{k});
    
    phaseminutes = (max(eye.timeeachphase{k}-min(eye.timeeachphase{k}))) / 60;
    saccade.rightperminute{k} = numel(saccade.righteye{k}) / phaseminutes;
    saccade.leftperminute{k}  = numel(saccade.lefteye{k})  / phaseminutes;

%     [~,~,interval.fitparamsright{k}] = posthoc_fitinterval(eye.timeeachphase{k},eye.rightposeachphase{k},saccade.righteye{k});  
%     [~,~,interval.fitparamsleft{k}]  = posthoc_fitinterval(eye.timeeachphase{k},eye.leftposeachphase{k}, saccade.lefteye{k});  

    % For this chunk of data (= this stimulus phase), fit lines to all slow
    % phase intervals you can find, and keep the best fit parameters.
    [a,b,c,rightfullparams] = PostHocFitInterval(eye.timeeachphase{k},eye.rightposeachphase{k},saccade.righteye{k},slowpause,slowduration);  
    [d,e,f,leftfullparams]  = PostHocFitInterval(eye.timeeachphase{k},eye.leftposeachphase{k}, saccade.lefteye{k},slowpause,slowduration);
    interval.rightfittime{k}  = a;
    interval.rightfitindex{k} = b;
    interval.rightfitvalue{k} = c;
    interval.leftfittime{k}   = d;
    interval.leftfitindex{k}  = e;
    interval.leftfitvalue{k}  = f;
    
    % Of these best fit parameters, we only really care about the slope.
    % The following line extracts only the slope of RIGHT-eye slow-phase
    % movements within this stimulus phase k.
    if isempty(rightfullparams)
      interval.fitsloperight{k} = [];
    else
      interval.fitsloperight{k} = rightfullparams(:,2);
    end
    
    % The following line extracts only the slope of LEFT-eye slow-phase
    % movements within this stimulus phase k.
    if isempty(leftfullparams)
      interval.fitslopeleft{k} = []; 
    else
      interval.fitslopeleft{k} = leftfullparams(:,2);
    end

  end

end
